@@ -23,8 +23,9 @@ class FileAdmin(admin.StackedInline):
 
 
 class StaffAdmin(TendenciBaseModelAdmin):
-    list_display = ['name', 'slug', 'department', 'phone', 'status']
+    list_display = ['name', 'slug', 'department', 'phone', 'status', 'position']
     list_filter = ['department', 'status']
+    list_editable = ['position']
     search_fields = ['name', 'biography', 'cv']
     prepopulated_fields = {'slug': ['name']}
     fieldsets = (
@@ -61,6 +62,7 @@ class StaffAdmin(TendenciBaseModelAdmin):
             '%sjs/jquery_ui_all_custom/jquery-ui-1.8.5.custom.min.js' % settings.STATIC_URL,
             '%sjs/admin/staff-dynamic-sort.js' % settings.STATIC_URL,
             '%sjs/global/tinymce.event_handlers.js' % settings.STATIC_URL,
+            '%sjs/admin/admin-list-reorder.js' % settings.STATIC_URL,
         )
         css = {'all': ['%scss/admin/dynamic-inlines-with-sort.css' % settings.STATIC_URL], }
 
